==> chainwallet-1.0.2.tar.gz: lib/src/core/coretypes/AccountID.dart <==
import 'dart:core';
import 'dart:collection';
import 'dart:core' as prefix0;
import "dart:typed_data";
import "../serialized/SerializedType.dart";
import "../fields/Field.dart";
import "../format/Format.dart";
import "../fields/Type.dart";
import "../serialized/BytesSink.dart";
import "../serialized/BinarySerializer.dart";
import "../serialized/TypeTranslator.dart";

import 'package:chainwallet/src/utils/Util.dart';

import 'package:chainwallet/src/core/coretypes/uint/UInt16.dart';
import 'package:chainwallet/src/core/serialized/BinaryParser.dart';
import 'package:chainwallet/src/core/coretypes/hash/Hash160.dart';

import 'package:chainwallet/src/core/coretypes/uint/UInt32.dart';

import 'package:chainwallet/src/utils/B58IdentiferCodecs.dart';


/**
 * Originally it was intended that AccountIDs would be variable length so that's
 * why they are variable length encoded as top level field objects.
 *
 * Note however, that in practice, all account ids are just 160 bit hashes.
 * Consider the fields TakerPaysIssuer and fixed length encoding of issuers in
 * amount serializations.
 *
 * Thus, we extend Hash160 which affords us some functionality.
 */
class AccountID extends Hash160 {

  String address;
  static AccountIDTranslator translate = new AccountIDTranslator();

  static AccountID NEUTRAL = fromInteger(BigInt.from(1)), XRP_ISSUER = fromInteger(BigInt.from(0));


  static Map<String, AccountID> aliases = new HashMap();

  AccountID(Uint8List bytes):super(bytes) {
      this.setAccountID(bytes, encodeAddress(bytes));
  }

  static AccountID fromInteger(BigInt n) {
    // The hash160 constructor will extend the 4bytes address
    var int32 = new UInt32(n);
    var hash160 = new Hash160(int32.toBytes());
    return fromBytes(hash160.toBytes());
  }

  static String encodeAddress(Uint8List a) {
        return B58IdentiferCodecs.encodeAddress(a);
  }

  static AccountID fromBytes(Uint8List bytes) {
        return new AccountID(bytes);
  }

  static  AccountID fromAddressBytes(Uint8List bytes) {
      return fromBytes(bytes);
  }

  /**
   * fromAddress
   * @param address Account address.
   * @return AccountID.
   */
  static AccountID fromAddress(String address) {

    var bytes = B58IdentiferCodecs.decodeAddress(address);

   // print(Util.formatBytesAsHexString(bytes));

    return new AccountID(bytes);
  }

  static AccountID accountForAlias(String value) {
    return aliases[value];
  }

  static AccountID fromString(String value) {

    if (value.length == 160 / 4) {
      return fromAddressBytes(Util.createUint8ListFromString(value));
    } else {
      if (value.startsWith("z") && value.length >= 26) {
        return fromAddress(value);
      }
      AccountID accountID = accountForAlias(value);
      if (accountID == null) {
        throw new Exception("Alias unset: " + value);
      }
      return accountID;
    }
  }

  void setAccountID(Uint8List bytes, String address){
    this.address = address;
  }




  Map toJSON() => null;
  Uint8List toBytes() => translate.toBytes(this);
  String toHex() => null;



  void toBytesSink(BytesSink to) {



      to.addBytes(bytes());

      var tmp = bytes();
  }

  String toString() => address;



  Type type() => Type.AccountID;



}



class  AccountIDTranslator extends   TypeTranslator<AccountID> {

//  AccountID fromParser(BinaryParser parser, int hint) {
//    return newInstance(parser.read(byteWidth()));
//  }

  AccountID fromParser(BinaryParser parser, int hint) {
    if (hint == null) {
      hint = 20;
    }
    return AccountID.fromAddressBytes(parser.read(hint));
  }

  AccountID fromString(String value) {
      return AccountID.fromString(value);
  }

}

==> chainwallet-1.0.4.tar.gz: lib/src/core/coretypes/AccountID.dart <==
import 'dart:core';
import 'dart:collection';
import 'dart:core' as prefix0;
import "dart:typed_data";
import "../serialized/SerializedType.dart";
import "../fields/Field.dart";
import "../format/Format.dart";
import "../fields/Type.dart";
import "../serialized/BytesSink.dart";
import "../serialized/BinarySerializer.dart";
import "../serialized/TypeTranslator.dart";

import 'package:chainwallet/src/utils/Util.dart';

import 'package:chainwallet/src/core/coretypes/uint/UInt16.dart';
import 'package:chainwallet/src/core/serialized/BinaryParser.dart';
import 'package:chainwallet/src/core/coretypes/hash/Hash160.dart';

import 'package:chainwallet/src/core/coretypes/uint/UInt32.dart';

import 'package:chainwallet/src/utils/B58IdentiferCodecs.dart';

/**
 * Originally it was intended that AccountIDs would be variable length so that's
 * why they are variable length encoded as top level field objects.
 *
 * Note however, that in practice, all account ids are just 160 bit hashes.
 * Consider the fields TakerPaysIssuer and fixed length encoding of issuers in
 * amount serializations.
 *
 * Thus, we extend Hash160 which affords us some functionality.
 */
class AccountID extends Hash160 {
  String address;
  static AccountIDTranslator translate = new AccountIDTranslator();

  static AccountID NEUTRAL = fromInteger(BigInt.from(1)),
      XRP_ISSUER = fromInteger(BigInt.from(0));

  static Map<String, AccountID> aliases = new HashMap();

  AccountID(Uint8List bytes) : super(bytes) {
    this.setAccountID(bytes, encodeAddress(bytes));
  }

  static AccountID fromInteger(BigInt n) {
    // The hash160 constructor will extend the 4bytes address
    var int32 = new UInt32(n);
    var hash160 = new Hash160(int32.toBytes());
    return fromBytes(hash160.toBytes());
  }

  static String encodeAddress(Uint8List a) {
    return B58IdentiferCodecs.encodeAddress(a);
  }

  static AccountID fromBytes(Uint8List bytes) {
    return new AccountID(bytes);
  }

  static AccountID fromAddressBytes(Uint8List bytes) {
    return fromBytes(bytes);
  }

  /**
   * fromAddress
   * @param address Account address.
   * @return AccountID.
   */
  static AccountID fromAddress(String address) {
    var bytes = B58IdentiferCodecs.decodeAddress(address);

    // print(Util.formatBytesAsHexString(bytes));

    return new AccountID(bytes);
  }

  static AccountID accountForAlias(String value) {
    return aliases[value];
  }

  static AccountID fromString(String value) {
    if (value.length == 160 / 4) {
      return fromAddressBytes(Util.createUint8ListFromString(value));
    } else {
      if (value.startsWith("z") && value.length >= 26) {
        return fromAddress(value);
      }
      AccountID accountID = accountForAlias(value);
      if (accountID == null) {
        throw new Exception("Alias unset: " + value);
      }
      return accountID;
    }
  }

  void setAccountID(Uint8List bytes, String address) {
    this.address = address;
  }

  Map toJSON() => null;
  Uint8List toBytes() => translate.toBytes(this);
  String toHex() => null;

  void toBytesSink(BytesSink to) {
    to.addBytes(bytes());

    var tmp = bytes();
  }

  String toString() => address;

  Type type() => Type.AccountID;
}

class AccountIDTranslator extends TypeTranslator<AccountID> {
//  AccountID fromParser(BinaryParser parser, int hint) {
//    return newInstance(parser.read(byteWidth()));
//  }

  AccountID fromParser(BinaryParser parser, int hint) {
    if (hint == null) {
      hint = 20;
    }
    return AccountID.fromAddressBytes(parser.read(hint));
  }

  AccountID fromString(String value) {
    return AccountID.fromString(value);
  }
}
